clld
====

Cross Linguistic Linked Data python library

Documentation for the code base and its use is available at http://clld.readthedocs.org/en/latest/. The source for this documentation is in the `docs` directory.

[![Build Status](https://travis-ci.org/clld/clld.png)](https://travis-ci.org/clld/clld)
[![codecov](https://codecov.io/gh/clld/clld/branch/master/graph/badge.svg)](https://codecov.io/gh/clld/clld)
[![Requirements Status](https://requires.io/github/clld/clld/requirements.svg?branch=master)](https://requires.io/github/clld/clld/requirements/?branch=master)
[![PyPI](https://img.shields.io/pypi/v/clld.svg)](https://pypi.python.org/pypi/clld)
[![Documentation Status](http://readthedocs.org/projects/clld/badge/?version=latest)](http://clld.readthedocs.io/en/latest/?badge=latest)


Cite
----

Most recent version:
https://doi.org/10.5281/zenodo.592412
